==> SmugMug-3.5.6.0.zip: SmugMug.lrplugin/SmAuth.lua <==
LuaQ                    E      A@   E    \      ŀ  A ܀ 
  	A	AB	BE  A  $  \AC dB                         	     	        	B              	    	              	           	B    	             import        LrHttp        require        SmAPI 	       SmLogger 	       SmPlugin        TOKEN_NOTAUTHORIZED        NotAuthorized        TOKEN_AUTHORIZED        Authorized        TOKEN_REVOKED        Revoked 
       setmetatable        __tostring        getAccessToken        getLocalizedTokenStatus        getRequestToken        handleCallback        notAuthorized        openUrl        registerCallback        revokeToken 
              !                          < SmAuth namespace >                         +   b           B@@     B  D F  
 J  I A I  "C @\BA  CC    C  UBW  C܂     C ܂  @ C ܂   E   BFEFCBW B@B  Ƃ@     Ë    @      @   
  	A   	  B  ܂ W@   E G\ MC  FL	CËCBC C @     @  @   @CB C      @             POST        buildQueryString        post        field        User-Agent        value 
       getUserAgent 
       Content-Type "       application/x-www-form-urlencoded        debug        HTTP Status:  	       tostring        status        none         httpSuccess        assert        match        oauth_token=([^&]+)        oauth_token_secret=([^&]+)        error        name        NONCE_USED        oauth_signature        TIMESTAMP_REFUSED        getServerResponseTime 
       apiTimeShift 	       tonumber        oauth_timestamp -       Attempting to auto correct invalid timestamp &       Can not auto correct Timestamp Offset                         f   y    
"   J  IA IW  I  AAAWA BA  B   B  B       @ 		            auth_token        auth_token_secret         oauth_verifier        prefs        UseUrlHandler        string        format ,       https://%s/services/oauth/getAccessToken.mg        HOST .       https://%s/services/oauth/1.0a/getAccessToken                         }          D   F  @   E@    ]  ^   D   F @   E@    ]  ^   E@  @ ]  ^               TOKEN_REVOKED        LOC )       $$$/SmugMug/Status/Token/Revoked=Revoked        TOKEN_NOTAUTHORIZED ^       $$$/SmugMug/Status/Token/NotAuthorized=To begin, connect Lightroom with your SmugMug account. /       $$$/SmugMug/Status/Token/Authorized=Authorized                                "       @W@   @    A D F܀ @@   @    A D F܀ 	B	B     @         
          prefs        UseUrlHandler        string        format -       https://%s/services/oauth/getRequestToken.mg        HOST        oauth_callback *       lightroom://com.smugmug.lightroom.publish /       https://%s/services/oauth/1.0a/getRequestToken        auth_token         auth_token_secret                                   K @ @  \      A                @             match        oauth_verifier=([^&]+)        import        LrTasks        startAsyncTask                    &       @ D      @@  A   @ D     @    A W@A     A A     A D  @  	@B                    
          getAccessToken        require 
       SmAccount        sync        auth_token                 notAuthorized        tokenRefreshing                                                	@@	@@	@	@@	@	@@	@D   F@ 	@   
          uid  	       nickname 	       fullname        email        plan        auth_token        auth_token_secret        tokenStatus        TOKEN_NOTAUTHORIZED                                
   D   F     \ A       E  F  A  \  AA A @BA      	          getRequestToken U       https://%s/services/oauth/authorize.mg?oauth_token=%s&Access=Full&Permissions=Modify         string        format        HOST        openUrlInBrowser        debug 
       AuthUrl:                                       H                                             	@@	@@D   F  	@            auth_token         auth_token_secret        tokenStatus        TOKEN_REVOKED                             

==> SmugMug-3.5.9.1.zip: SmugMug.lrplugin/SmAuth.lua <==
LuaQ                    E      A@   E    \      ŀ  A ܀ 
  	A	AB	BE  A  $  \AC dB                         	     	        	B              	    	              	           	B    	             import        LrHttp        require        SmAPI 	       SmLogger 	       SmPlugin        TOKEN_NOTAUTHORIZED        NotAuthorized        TOKEN_AUTHORIZED        Authorized        TOKEN_REVOKED        Revoked 
       setmetatable        __tostring        getAccessToken        getLocalizedTokenStatus        getRequestToken        handleCallback        notAuthorized        openUrl        registerCallback        revokeToken 
              !                          < SmAuth namespace >                         +   b           B@@     B  D F  
 J  I A I  "C @\BA  CC    C  UBW  C܂     C ܂  @ C ܂   E   BFEFCBW B@B  Ƃ@     Ë    @      @   
  	A   	  B  ܂ W@   E G\ MC  FL	CËCBC C @     @  @   @CB C      @             POST        buildQueryString        post        field        User-Agent        value 
       getUserAgent 
       Content-Type "       application/x-www-form-urlencoded        trace        HTTP Status:  	       tostring        status        none         httpSuccess        assert        match        oauth_token=([^&]+)        oauth_token_secret=([^&]+)        error        name        NONCE_USED        oauth_signature        TIMESTAMP_REFUSED        getServerResponseTime 
       apiTimeShift 	       tonumber        oauth_timestamp -       Attempting to auto correct invalid timestamp &       Can not auto correct Timestamp Offset                         f   y    
"   J  IA IW  I  AAAWA BA  B   B  B       @ 		            auth_token        auth_token_secret         oauth_verifier        prefs        UseUrlHandler        string        format ,       https://%s/services/oauth/getAccessToken.mg        HOST .       https://%s/services/oauth/1.0a/getAccessToken                         }          D   F  @   E@    ]  ^   D   F @   E@    ]  ^   E@  @ ]  ^               TOKEN_REVOKED        LOC )       $$$/SmugMug/Status/Token/Revoked=Revoked        TOKEN_NOTAUTHORIZED ^       $$$/SmugMug/Status/Token/NotAuthorized=To begin, connect Lightroom with your SmugMug account. /       $$$/SmugMug/Status/Token/Authorized=Authorized                                "       @W@   @    A D F܀ @@   @    A D F܀ 	B	B     @         
          prefs        UseUrlHandler        string        format -       https://%s/services/oauth/getRequestToken.mg        HOST        oauth_callback *       lightroom://com.smugmug.lightroom.publish /       https://%s/services/oauth/1.0a/getRequestToken        auth_token         auth_token_secret                                   K @ @  \      A                @             match        oauth_verifier=([^&]+)        import        LrTasks        startAsyncTask                    &       @ D      @@  A   @ D     @    A W@A     A A     A D  @  	@B                    
          getAccessToken        require 
       SmAccount        sync        auth_token                 notAuthorized        tokenRefreshing                                                	@@	@@	@	@@	@	@@	@D   F@ 	@   
          uid  	       nickname 	       fullname        email        plan        auth_token        auth_token_secret        tokenStatus        TOKEN_NOTAUTHORIZED                                
   D   F     \ A       E  F  A  \  AA A @BA      	          getRequestToken U       https://%s/services/oauth/authorize.mg?oauth_token=%s&Access=Full&Permissions=Modify         string        format        HOST        openUrlInBrowser        trace 
       AuthUrl:                                       H                                             	@@	@@D   F  	@            auth_token         auth_token_secret        tokenStatus        TOKEN_REVOKED                             
